@@ -1,5 +1,7 @@
 package Plack::Middleware::Debug::Mongo::ServerStatus;
 
+# ABSTRACT: Server status debug panel for Plack::Middleware::Debug
+
 use strict;
 use warnings;
 use parent 'Plack::Middleware::Debug::Base';
@@ -7,7 +9,8 @@ use Plack::Util::Accessor qw/connection mongo_client/;
 use MongoDB 0.502;
 use Exporter 'import';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03'; # VERSION
+our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY
 
 our %EXPORT_TAGS = (
     'all' => [ qw(hashwalk) ]
@@ -70,6 +73,7 @@ sub hashwalk {
 }
 
 1; # End of Plack::Middleware::Debug::Mongo::ServerStatus
+
 __END__
 
 =pod
@@ -80,7 +84,7 @@ Plack::Middleware::Debug::Mongo::ServerStatus - Server status debug panel for Pl
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -156,13 +160,13 @@ L<MongoDB Server Status Reference|http://docs.mongodb.org/manual/reference/serve
 
 =head1 AUTHOR
 
-Anton Gerasimov, E<lt>chim@cpan.orgE<gt>
+Anton Gerasimov <chim@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Anton Gerasimov
+This software is copyright (c) 2013 by Anton Gerasimov.
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
